@@ -125,7 +125,7 @@ sharing_plugin_interface_send (SharingTransfer *transfer,
   retval = picasa_post_upload_to_service (transfer, con,
 					  dead_mans_switch);
 
-  ULOG_DEBUG_L ("%s: Returnign with %d",fn,retval);
+  ULOG_DEBUG_L ("%s: Returning with %d",fn,retval);
 
   return retval;
 }
@@ -150,7 +150,7 @@ sharing_plugin_interface_account_setup (GtkWindow* parent,
   ULOG_DEBUG_L ("%s: SharingAccount = %0X",fn, (guint)*worked_on);
   ULOG_DEBUG_L ("%s: Sharing service = %s",fn,sharing_service_get_name(service));
 
-  ULOG_DEBUG_L ("%s: Returnig with %d",fn,retval);
+  ULOG_DEBUG_L ("%s: Returning with %d",fn,retval);
 
   return retval;
 }
@@ -290,7 +290,7 @@ sharing_plugin_interface_update_options (SharingAccount* account,
     retval = TRUE;
   }
 
-  ULOG_DEBUG_L ("%s: returning", fn);
+  ULOG_DEBUG_L ("%s: Returning", fn);
   g_free (data);
 					   
   return retval;
