@@ -249,11 +249,13 @@ picasa_post_convert_send_response (picasa_post_response_t res) {
     if (g_strcmp0 (res.msg, PICASA_POST_FILE_TOO_LARGE_C) == 0) {
       result = SHARING_SEND_ERROR_UPLOAD_LIMIT;
     }
+    else if (g_strcmp0 (res.msg, PICASA_POST_NOT_AN_IMAGE_C) == 0) {
+      result = SHARING_SEND_ERROR_FILE_FORMAT;
+    }
     else {
       result = SHARING_SEND_ERROR_UNKNOWN;
     }
     break;
-
   case HTTP_FAILED:
     if (g_strcmp0 (res.msg, PICASA_POST_BAD_AUTHENTICATION_C) == 0) {
       result = SHARING_SEND_ERROR_AUTH;
@@ -1301,7 +1303,7 @@ picasa_post_upload_to_service (SharingTransfer *transfer,
 	picasa_post_add_tags (media, con, &data);
 	status = SHARING_SEND_SUCCESS;
       } else {
-	ULOG_DEBUG_L ("%s: sending to service failed %d",fn,status);
+	ULOG_DEBUG_L ("%s: sending to service failed %d", fn, res.code);
 	status = picasa_post_convert_send_response (res);
 	break;
       }
