@@ -67,6 +67,10 @@ typedef enum {
    PICASA_POST_FILE_TOO_BIG_C
 */
 #define PICASA_POST_FILE_TOO_LARGE_C "Image too large."
+/**
+   PICASA_POST_NOT_AN_IMAGE_C
+*/
+#define PICASA_POST_NOT_AN_IMAGE_C "Not an image."
 
 
 #ifdef WITH_ALBUM_SUPPORT
